Progress Bar Timer Example
===============================================================================

:download:`progress_bar_timer.enaml
<../../../examples/components/progress_bar_timer.enaml>`

.. literalinclude:: ../../../examples/components/progress_bar_timer.enaml
    :language: python

::

 $ enaml-run progress_bar_timer.enaml

.. image:: images/progress_bar_timer.png
